@@ -24,7 +24,10 @@ impl Procedures for Cash {
 }
 
 impl Cash {
-    fn mata() -> String {
-        String::from("mata")
+    pub fn new(currency: String, amount: i64) -> Self {
+        Self {
+            currency: String::from(currency),
+            amount: amount,
+        }
     }
 }
\ No newline at end of file
